@@ -12,8 +12,5 @@ async fn main() {
     let router = Router::new()
         .hoop(auth_handler)
         .get(StaticDir::new(vec!["examples/static/boy", "examples/static/girl"]));
-    Server::bind(&"127.0.0.1:7878".parse().unwrap())
-        .serve(Service::new(router))
-        .await
-        .unwrap();
+    Server::new(TcpListener::bind(([0, 0, 0, 0], 7878))).serve(router).await;
 }
