@@ -26,8 +26,5 @@ async fn main() {
                 .path("examples/<*path>")
                 .get(StaticDir::new("examples/")),
         );
-    Server::bind(&"127.0.0.1:7878".parse().unwrap())
-        .serve(Service::new(router))
-        .await
-        .unwrap();
+    Server::new(TcpListener::bind(([0, 0, 0, 0], 7878))).serve(router).await;
 }
