@@ -16,8 +16,5 @@ async fn main() {
         .build();
 
     let router = Router::with_hoop(cors_handler).get(hello);
-    Server::bind(&"127.0.0.1:7878".parse().unwrap())
-        .serve(Service::new(router))
-        .await
-        .unwrap();
+    Server::new(TcpListener::bind(([0, 0, 0, 0], 7878))).serve(router).await;
 }
