@@ -13,10 +13,9 @@ async fn main() {
     let router = Router::new().get(hello_world);
     let catcher: Vec<Box<dyn Catcher>> = vec![Box::new(Handle404)];
     let service = Service::new(router).with_catchers(catcher);
-    Server::bind(&"127.0.0.1:7878".parse().unwrap())
+    Server::new(TcpListener::bind(([0, 0, 0, 0], 7878)))
         .serve(service)
-        .await
-        .unwrap();
+        .await;
 }
 
 struct Handle404;
