@@ -13,8 +13,5 @@ async fn main() {
             defaults: vec!["index.html".to_owned()],
         },
     ));
-    Server::bind(&"127.0.0.1:7878".parse().unwrap())
-        .serve(Service::new(router))
-        .await
-        .unwrap();
+    Server::new(TcpListener::bind(([0, 0, 0, 0], 7878))).serve(router).await;
 }
