@@ -17,8 +17,8 @@ async fn main() {
     let router2 = Router::new().get(hello_world2);
 
     tokio::try_join!(
-        Server::bind(&"127.0.0.1:7979".parse().unwrap()).serve(Service::new(router1)),
-        Server::bind(&"127.0.0.1:7878".parse().unwrap()).serve(Service::new(router2))
+        Server::new(TcpListener::bind(([0, 0, 0, 0], 7878))).try_serve(router1),
+        Server::new(TcpListener::bind(([0, 0, 0, 0], 7979))).try_serve(router2),
     )
     .unwrap();
 }
