@@ -36,8 +36,5 @@ async fn main() {
     tracing_subscriber::fmt().init();
 
     let router = Router::with_path("ticks").get(handle_tick);
-    Server::bind(&"127.0.0.1:7878".parse().unwrap())
-        .serve(Service::new(router))
-        .await
-        .unwrap();
+    Server::new(TcpListener::bind(([0, 0, 0, 0], 7878))).serve(router).await;
 }
